pub struct TsonEnumAccess<'de, 'a> { /* private fields */ }Trait Implementations
Sourceimpl<'de, 'a> EnumAccess<'de> for TsonEnumAccess<'de, 'a>
impl<'de, 'a> EnumAccess<'de> for TsonEnumAccess<'de, 'a>
Sourcetype Error = Error
type Error = Error
The error type that can be returned if some error occurs during
deserialization.
Sourcetype Variant = TsonEnumAccess<'de, 'a>
type Variant = TsonEnumAccess<'de, 'a>
The
Visitor that will be used to deserialize the content of the enum
variant.Sourcefn variant_seed<V>(
self,
seed: V,
) -> Result<(V::Value, Self::Variant), Self::Error>where
V: DeserializeSeed<'de>,
fn variant_seed<V>(
self,
seed: V,
) -> Result<(V::Value, Self::Variant), Self::Error>where
V: DeserializeSeed<'de>,
variant is called to identify which variant to deserialize. Read moreSourceimpl<'de, 'a> VariantAccess<'de> for TsonEnumAccess<'de, 'a>
impl<'de, 'a> VariantAccess<'de> for TsonEnumAccess<'de, 'a>
Sourcetype Error = Error
type Error = Error
The error type that can be returned if some error occurs during
deserialization. Must match the error type of our
EnumAccess.Sourcefn unit_variant(self) -> Result<(), Self::Error>
fn unit_variant(self) -> Result<(), Self::Error>
Called when deserializing a variant with no values. Read more
Sourcefn newtype_variant_seed<T>(self, seed: T) -> Result<T::Value, Self::Error>where
T: DeserializeSeed<'de>,
fn newtype_variant_seed<T>(self, seed: T) -> Result<T::Value, Self::Error>where
T: DeserializeSeed<'de>,
Called when deserializing a variant with a single value. Read more
Sourcefn tuple_variant<V>(
self,
_len: usize,
visitor: V,
) -> Result<V::Value, Self::Error>where
V: Visitor<'de>,
fn tuple_variant<V>(
self,
_len: usize,
visitor: V,
) -> Result<V::Value, Self::Error>where
V: Visitor<'de>,
Called when deserializing a tuple-like variant. Read more
Sourcefn struct_variant<V>(
self,
_fields: &'static [&'static str],
visitor: V,
) -> Result<V::Value, Self::Error>where
V: Visitor<'de>,
fn struct_variant<V>(
self,
_fields: &'static [&'static str],
visitor: V,
) -> Result<V::Value, Self::Error>where
V: Visitor<'de>,
Called when deserializing a struct-like variant. Read more
Sourcefn newtype_variant<T>(self) -> Result<T, Self::Error>where
T: Deserialize<'de>,
fn newtype_variant<T>(self) -> Result<T, Self::Error>where
T: Deserialize<'de>,
Called when deserializing a variant with a single value. Read more